@@ -1,24 +1,20 @@
+import math
 import os
+from typing import Union
 
-import torch.nn as nn
+import numpy as np
 import torch
-import unicodedata
-import re
-
+import torch.nn as nn
 import yaml
 from sklearn.cluster import KMeans
-from typing import Union
-import numpy as np
-import math
 
-from .cli import fprint, Cp, print_model, attar_print
+from .command_line_interface import fprint, Cp, print_model, attar_print
 
 Any = Union[list, dict, int, float, str]
 
 
 def arg_creator(arg: list = None, prefix=None):
     '''
-
     :param arg: args from list to pythonic like *args
     :param prefix: to use for first arg
     :return: args
@@ -144,9 +140,9 @@ def name_to_layer(name: str, attr: Any = None, in_case_prefix_use=None, prefix:
     return model
 
 
-def module_creator(backbone, head, print_status, ic_backbone, nc, anchors):
+def module_creator(backbone, head, print_status, ic_backbone, nc, anchors, in_case_prefix_use):
     model = nn.ModuleList()
-    save, sv_bb, in_case_prefix_use = [], [], ['Conv']
+    save, sv_bb = [], []
     model_list = backbone + head
     sva, idx = 0, 0
     for i, at in enumerate(model_list):
